@@ -62,7 +62,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 35 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:339  */
+#line 35 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:339  */
 
 #ifdef HAVE_DMX_CONFIG_H
 #include <dmx-config.h>
@@ -75,6 +75,7 @@
 #define YYERROR_VERBOSE
 #define YY_USE_PROTOS
 
+extern int yylex(void);
 DMXConfigEntryPtr dmxConfigEntry = NULL;
 #define APPEND(type, h, t)                 \
 {                                          \
@@ -83,7 +84,7 @@ DMXConfigEntryPtr dmxConfigEntry = NULL;
     pt->next = t;                          \
 }
 
-#line 87 "parser.c" /* yacc.c:339  */
+#line 88 "parser.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -149,7 +150,7 @@ extern int yydebug;
 
 union YYSTYPE
 {
-#line 56 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:355  */
+#line 57 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:355  */
 
     DMXConfigTokenPtr      token;
     DMXConfigStringPtr     string;
@@ -166,7 +167,7 @@ union YYSTYPE
     DMXConfigVirtualPtr    virtual;
     DMXConfigEntryPtr      entry;
 
-#line 170 "parser.c" /* yacc.c:355  */
+#line 171 "parser.c" /* yacc.c:355  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -183,7 +184,7 @@ int yyparse (void);
 
 /* Copy the second part of user declarations.  */
 
-#line 187 "parser.c" /* yacc.c:358  */
+#line 188 "parser.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -481,12 +482,12 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    95,    95,    98,    99,   102,   103,   106,   108,   110,
-     112,   116,   117,   120,   121,   122,   123,   124,   127,   131,
-     133,   139,   140,   143,   147,   149,   151,   155,   157,   159,
-     163,   165,   167,   170,   172,   174,   176,   180,   182,   184,
-     188,   189,   192,   193,   196,   197,   200,   201,   204,   205,
-     208,   209,   212,   213,   216,   217,   220,   221,   224,   225
+       0,    96,    96,    99,   100,   103,   104,   107,   109,   111,
+     113,   117,   118,   121,   122,   123,   124,   125,   128,   132,
+     134,   140,   141,   144,   148,   150,   152,   156,   158,   160,
+     164,   166,   168,   171,   173,   175,   177,   181,   183,   185,
+     189,   190,   193,   194,   197,   198,   201,   202,   205,   206,
+     209,   210,   213,   214,   217,   218,   221,   222,   225,   226
 };
 #endif
 
@@ -1319,279 +1320,279 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 95 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 96 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { dmxConfigEntry = (yyvsp[0].entry); }
-#line 1325 "parser.c" /* yacc.c:1646  */
+#line 1326 "parser.c" /* yacc.c:1646  */
     break;
 
   case 4:
-#line 99 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 100 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { APPEND(DMXConfigEntryPtr,(yyvsp[-1].entry),(yyvsp[0].entry)); (yyval.entry) = (yyvsp[-1].entry); }
-#line 1331 "parser.c" /* yacc.c:1646  */
+#line 1332 "parser.c" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 102 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 103 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.entry) = dmxConfigEntryVirtual((yyvsp[0].virtual)); }
-#line 1337 "parser.c" /* yacc.c:1646  */
+#line 1338 "parser.c" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 103 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 104 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.entry) = dmxConfigEntryComment((yyvsp[0].comment)); }
-#line 1343 "parser.c" /* yacc.c:1646  */
+#line 1344 "parser.c" /* yacc.c:1646  */
     break;
 
   case 7:
-#line 107 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 108 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.virtual) = dmxConfigCreateVirtual((yyvsp[-3].token), NULL, NULL, (yyvsp[-2].token), (yyvsp[-1].subentry), (yyvsp[0].token)); }
-#line 1349 "parser.c" /* yacc.c:1646  */
+#line 1350 "parser.c" /* yacc.c:1646  */
     break;
 
   case 8:
-#line 109 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 110 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.virtual) = dmxConfigCreateVirtual((yyvsp[-4].token), NULL, (yyvsp[-3].pair), (yyvsp[-2].token), (yyvsp[-1].subentry), (yyvsp[0].token)); }
-#line 1355 "parser.c" /* yacc.c:1646  */
+#line 1356 "parser.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 111 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 112 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.virtual) = dmxConfigCreateVirtual((yyvsp[-4].token), (yyvsp[-3].string), NULL, (yyvsp[-2].token), (yyvsp[-1].subentry), (yyvsp[0].token)); }
-#line 1361 "parser.c" /* yacc.c:1646  */
+#line 1362 "parser.c" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 113 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 114 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.virtual) = dmxConfigCreateVirtual((yyvsp[-5].token), (yyvsp[-4].string), (yyvsp[-3].pair), (yyvsp[-2].token), (yyvsp[-1].subentry), (yyvsp[0].token) ); }
-#line 1367 "parser.c" /* yacc.c:1646  */
+#line 1368 "parser.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 117 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 118 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { APPEND(DMXConfigSubPtr,(yyvsp[-1].subentry),(yyvsp[0].subentry)); (yyval.subentry) = (yyvsp[-1].subentry); }
-#line 1373 "parser.c" /* yacc.c:1646  */
+#line 1374 "parser.c" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 120 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 121 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.subentry) = dmxConfigSubComment((yyvsp[0].comment)); }
-#line 1379 "parser.c" /* yacc.c:1646  */
+#line 1380 "parser.c" /* yacc.c:1646  */
     break;
 
   case 14:
-#line 121 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 122 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.subentry) = dmxConfigSubDisplay((yyvsp[0].display)); }
-#line 1385 "parser.c" /* yacc.c:1646  */
+#line 1386 "parser.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 122 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 123 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.subentry) = dmxConfigSubWall((yyvsp[0].wall)); }
-#line 1391 "parser.c" /* yacc.c:1646  */
+#line 1392 "parser.c" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 123 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 124 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.subentry) = dmxConfigSubOption((yyvsp[0].option)); }
-#line 1397 "parser.c" /* yacc.c:1646  */
+#line 1398 "parser.c" /* yacc.c:1646  */
     break;
 
   case 17:
-#line 124 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 125 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.subentry) = dmxConfigSubParam((yyvsp[0].param)); }
-#line 1403 "parser.c" /* yacc.c:1646  */
+#line 1404 "parser.c" /* yacc.c:1646  */
     break;
 
   case 18:
-#line 128 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 129 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.option) = dmxConfigCreateOption((yyvsp[-2].token), (yyvsp[-1].string), (yyvsp[0].token)); }
-#line 1409 "parser.c" /* yacc.c:1646  */
+#line 1410 "parser.c" /* yacc.c:1646  */
     break;
 
   case 19:
-#line 132 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 133 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.param) = dmxConfigCreateParam((yyvsp[-2].token), NULL, (yyvsp[-1].string), NULL, (yyvsp[0].token)); }
-#line 1415 "parser.c" /* yacc.c:1646  */
+#line 1416 "parser.c" /* yacc.c:1646  */
     break;
 
   case 20:
-#line 134 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 135 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.param) = dmxConfigCreateParam((yyvsp[-3].token), (yyvsp[-2].token), NULL, (yyvsp[0].token), NULL);
                (yyval.param)->next = (yyvsp[-1].param);
              }
-#line 1423 "parser.c" /* yacc.c:1646  */
+#line 1424 "parser.c" /* yacc.c:1646  */
     break;
 
   case 22:
-#line 140 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 141 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { APPEND(DMXConfigParamPtr,(yyvsp[-1].param),(yyvsp[0].param)); (yyval.param) = (yyvsp[-1].param); }
-#line 1429 "parser.c" /* yacc.c:1646  */
+#line 1430 "parser.c" /* yacc.c:1646  */
     break;
 
   case 23:
-#line 144 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 145 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.param) = dmxConfigCreateParam(NULL, NULL, (yyvsp[-1].string), NULL, (yyvsp[0].token)); }
-#line 1435 "parser.c" /* yacc.c:1646  */
+#line 1436 "parser.c" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 148 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 149 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.pdim) = dmxConfigCreatePartDim((yyvsp[-1].pair), (yyvsp[0].pair)); }
-#line 1441 "parser.c" /* yacc.c:1646  */
+#line 1442 "parser.c" /* yacc.c:1646  */
     break;
 
   case 25:
-#line 150 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 151 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.pdim) = dmxConfigCreatePartDim((yyvsp[0].pair), NULL); }
-#line 1447 "parser.c" /* yacc.c:1646  */
+#line 1448 "parser.c" /* yacc.c:1646  */
     break;
 
   case 26:
-#line 152 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 153 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.pdim) = dmxConfigCreatePartDim(NULL, (yyvsp[0].pair)); }
-#line 1453 "parser.c" /* yacc.c:1646  */
+#line 1454 "parser.c" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 156 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 157 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.fdim) = dmxConfigCreateFullDim((yyvsp[-2].pdim), (yyvsp[0].pdim)); }
-#line 1459 "parser.c" /* yacc.c:1646  */
+#line 1460 "parser.c" /* yacc.c:1646  */
     break;
 
   case 28:
-#line 158 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 159 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.fdim) = dmxConfigCreateFullDim(NULL, (yyvsp[0].pdim)); }
-#line 1465 "parser.c" /* yacc.c:1646  */
+#line 1466 "parser.c" /* yacc.c:1646  */
     break;
 
   case 29:
-#line 160 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 161 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.fdim) = dmxConfigCreateFullDim((yyvsp[0].pdim), NULL); }
-#line 1471 "parser.c" /* yacc.c:1646  */
+#line 1472 "parser.c" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 164 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 165 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.display) = dmxConfigCreateDisplay((yyvsp[-4].token), (yyvsp[-3].string), (yyvsp[-2].fdim), (yyvsp[-1].pair), (yyvsp[0].token)); }
-#line 1477 "parser.c" /* yacc.c:1646  */
+#line 1478 "parser.c" /* yacc.c:1646  */
     break;
 
   case 31:
-#line 166 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 167 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.display) = dmxConfigCreateDisplay((yyvsp[-3].token), NULL, (yyvsp[-2].fdim), (yyvsp[-1].pair), (yyvsp[0].token)); }
-#line 1483 "parser.c" /* yacc.c:1646  */
+#line 1484 "parser.c" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 168 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 169 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.display) = dmxConfigCreateDisplay((yyvsp[-3].token), (yyvsp[-2].string), NULL, (yyvsp[-1].pair), (yyvsp[0].token)); }
-#line 1489 "parser.c" /* yacc.c:1646  */
+#line 1490 "parser.c" /* yacc.c:1646  */
     break;
 
   case 33:
-#line 171 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 172 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.display) = dmxConfigCreateDisplay((yyvsp[-3].token), (yyvsp[-2].string), (yyvsp[-1].fdim), NULL, (yyvsp[0].token)); }
-#line 1495 "parser.c" /* yacc.c:1646  */
+#line 1496 "parser.c" /* yacc.c:1646  */
     break;
 
   case 34:
-#line 173 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 174 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.display) = dmxConfigCreateDisplay((yyvsp[-2].token), NULL, (yyvsp[-1].fdim), NULL, (yyvsp[0].token)); }
-#line 1501 "parser.c" /* yacc.c:1646  */
+#line 1502 "parser.c" /* yacc.c:1646  */
     break;
 
   case 35:
-#line 175 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 176 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.display) = dmxConfigCreateDisplay((yyvsp[-2].token), (yyvsp[-1].string), NULL, NULL, (yyvsp[0].token)); }
-#line 1507 "parser.c" /* yacc.c:1646  */
+#line 1508 "parser.c" /* yacc.c:1646  */
     break;
 
   case 36:
-#line 177 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 178 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.display) = dmxConfigCreateDisplay((yyvsp[-1].token), NULL, NULL, NULL, (yyvsp[0].token)); }
-#line 1513 "parser.c" /* yacc.c:1646  */
+#line 1514 "parser.c" /* yacc.c:1646  */
     break;
 
   case 37:
-#line 181 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 182 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.wall) = dmxConfigCreateWall((yyvsp[-4].token), (yyvsp[-3].pair), (yyvsp[-2].pair), (yyvsp[-1].string), (yyvsp[0].token)); }
-#line 1519 "parser.c" /* yacc.c:1646  */
+#line 1520 "parser.c" /* yacc.c:1646  */
     break;
 
   case 38:
-#line 183 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 184 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.wall) = dmxConfigCreateWall((yyvsp[-3].token), (yyvsp[-2].pair), NULL, (yyvsp[-1].string), (yyvsp[0].token)); }
-#line 1525 "parser.c" /* yacc.c:1646  */
+#line 1526 "parser.c" /* yacc.c:1646  */
     break;
 
   case 39:
-#line 185 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 186 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.wall) = dmxConfigCreateWall((yyvsp[-2].token), NULL, NULL, (yyvsp[-1].string), (yyvsp[0].token)); }
-#line 1531 "parser.c" /* yacc.c:1646  */
+#line 1532 "parser.c" /* yacc.c:1646  */
     break;
 
   case 41:
-#line 189 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 190 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.token) = (yyvsp[-1].token); (yyval.token)->comment = (yyvsp[0].comment)->comment; }
-#line 1537 "parser.c" /* yacc.c:1646  */
+#line 1538 "parser.c" /* yacc.c:1646  */
     break;
 
   case 43:
-#line 193 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 194 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.string) = (yyvsp[-1].string); (yyval.string)->comment = (yyvsp[0].comment)->comment; }
-#line 1543 "parser.c" /* yacc.c:1646  */
+#line 1544 "parser.c" /* yacc.c:1646  */
     break;
 
   case 45:
-#line 197 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 198 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.pair) = (yyvsp[-1].pair); (yyval.pair)->comment = (yyvsp[0].comment)->comment; }
-#line 1549 "parser.c" /* yacc.c:1646  */
+#line 1550 "parser.c" /* yacc.c:1646  */
     break;
 
   case 47:
-#line 201 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 202 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.pair) = (yyvsp[-1].pair); (yyval.pair)->comment = (yyvsp[0].comment)->comment; }
-#line 1555 "parser.c" /* yacc.c:1646  */
+#line 1556 "parser.c" /* yacc.c:1646  */
     break;
 
   case 49:
-#line 205 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 206 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.pair) = (yyvsp[-1].pair); (yyval.pair)->comment = (yyvsp[0].comment)->comment; }
-#line 1561 "parser.c" /* yacc.c:1646  */
+#line 1562 "parser.c" /* yacc.c:1646  */
     break;
 
   case 51:
-#line 209 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 210 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.token) = (yyvsp[-1].token); (yyval.token)->comment = (yyvsp[0].comment)->comment; }
-#line 1567 "parser.c" /* yacc.c:1646  */
+#line 1568 "parser.c" /* yacc.c:1646  */
     break;
 
   case 53:
-#line 213 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 214 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.token) = (yyvsp[-1].token); (yyval.token)->comment = (yyvsp[0].comment)->comment; }
-#line 1573 "parser.c" /* yacc.c:1646  */
+#line 1574 "parser.c" /* yacc.c:1646  */
     break;
 
   case 55:
-#line 217 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 218 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.token) = (yyvsp[-1].token); (yyval.token)->comment = (yyvsp[0].comment)->comment; }
-#line 1579 "parser.c" /* yacc.c:1646  */
+#line 1580 "parser.c" /* yacc.c:1646  */
     break;
 
   case 57:
-#line 221 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 222 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { (yyval.token) = (yyvsp[-1].token); (yyval.token)->comment = (yyvsp[0].comment)->comment; }
-#line 1585 "parser.c" /* yacc.c:1646  */
+#line 1586 "parser.c" /* yacc.c:1646  */
     break;
 
   case 59:
-#line 225 "/wip/cygport-git/xorg-server/xorg-server-1.18.0-2.i686/src/xserver-cygwin-1.18.0-2/hw/dmx/config/parser.y" /* yacc.c:1646  */
+#line 226 "/wip/cygport-git/xorg-server/xorg-server-1.18.1-1.x86_64/src/xserver-cygwin-1.18.1-1/hw/dmx/config/parser.y" /* yacc.c:1646  */
     { APPEND(DMXConfigStringPtr, (yyvsp[-1].string), (yyvsp[0].string)); (yyval.string) = (yyvsp[-1].string); }
-#line 1591 "parser.c" /* yacc.c:1646  */
+#line 1592 "parser.c" /* yacc.c:1646  */
     break;
 
 
-#line 1595 "parser.c" /* yacc.c:1646  */
+#line 1596 "parser.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
